declare module BA.Ui.Controls {
    class TokenBoxEvents {
        private static readonly ClearNameRegEx;
        private static readonly TokenInputSuffix;
        private static readonly PickListOpenerInListContainerSuffix;
        private static readonly TokenSelectionListSuffix;
        private static readonly TokenSelectionListContainerSuffix;
        private static readonly PreselectedTokenClass;
        private static readonly PreselectedTokenSelector;
        private static readonly FocusedOpenerClass;
        private static readonly FocusedOpenerSelector;
        private static readonly TokenResultContentClass;
        private static readonly TokenResultContentSelector;
        private static readonly TokenResultElementClass;
        private static readonly TokenResultElementSelector;
        /**
         * Hihglights the given keywords in the given string by surrounding them with html tags to make these parts bold.
         *
         * @param sourceString the string to search in
         * @param keywords keywords to search for and highlight
         */
        private static HighlightAppearances;
        /**
         * Event function for seleting a type-ahead result and adding a respective token.
         *
         * @param tokenControlName Name of the picklist or tokenlist control
         * @param oid the oid of the token
         * @param title the title of the token
         */
        private static ResultTokenPointerDown;
        private static OnTokenInputBlur;
        private static HandleTabAndEnter;
        private static PreSelectNext;
        private static PreSelectPrevious;
        private static DeleteLastToken;
        static TokenBoxTokensChanged(s: BASortableTokenBoxControl, e: ASPxClientEventArgs): void;
        static TokenBoxTokensInit(sender: any, e: any): void;
        static OnLinksTokenboxInit(s: any, e: any): void;
        static OnInputChanged(sender: any, evt: any): void;
        static OnKeyDown(sender: HTMLInputElement, evt: any): void;
        static OnKeyUp(sender: HTMLInputElement, evt: any): void;
        private static Search;
        static OnPaste(sender: any, evt: any): void;
        static UpdateResultsListPosition(tokenboxControl: BASortableTokenBoxControl): void;
        /******* SORTABLE TOKENBOX STUFF BELOW *******/
        static GetControl(name: string): BASortableTokenBoxControl;
        static GetHiddenControl(name: string): ASPxClientTextBox;
        /**
         * Initializes the sortable tokenbox control. As the sortable tokenbox is a simple devex label control, this
         * method can add several functions to the label object that help us in managing the tokens of the tokenbox.
         * In addition, it initializes drag and drop using dragula.js if applicable.
         * @param sender the "TokenBox" control
         * @param evt the init event object
         */
        static InitSortableTokenbox(sender: any, evt: any): void;
        private static UpdateHiddenCompanionIfChanged;
        static OnControlClick(sender: any, evt: any): void;
        static SortableTokenboxOpenerClicked(dlgParameters: CustomData, senderName: string): void;
        static SortableTokenboxOpenDialog(context: Window, onFinished: Function, afterStart: Function, controlName: string, additionalParameters: string): void;
        /**
         * Private helper function that creates html from the given token, that can be added to the control.
         *
         * @param token The token-data to be created
         * @param control The aspx label control representing the tokenbox control
         * @param readOnly true, if tokens may not be removed
         * @param sortable true, if tokens may be moved using drag and drop
         */
        private static CreateTokenHtml;
        /**
        * Invoked, when a token is double clicked. Tries to open the referenced record.
        *
        * @param oid The oid of the record to open
        * @param ormType The orm type of the record to open
        */
        static TryOpen(oid: string, ormType: string): void;
        /**
         * Creates a token object from the given grid view row (html element).
         *
         * @param row HTMLElement of some row of a grid view that displays records.
         */
        private static CreateTokenFromRow;
        /**
         * Private helper function that is called when the contents of the control are changed. It sets the current tab
         * as dirty and refreshes configured refresh groups.
         *
         * @param control The aspx label control representing the tokenbox control
         */
        private static OnChanged;
        /**
         * Private helper function that html-encodes the given string, thus turning special characters into entities.
         *
         * @param text text to be encoded
         */
        private static EncodeHTML;
        private static GetJQControl;
        private static ClearName;
    }
    /** Class that represents a token of the sortable token box */
    class Token {
        Oid: string;
        Title: string;
        Type: string;
        constructor(Oid: string, Title: string, Type: string);
    }
    /** Class that represents a token of the sortable token box */
    class TokenSearchResult {
        Oid: string;
        Title: string;
        Type: string;
        IconUrlNormal?: string;
        IconUrlHighlight?: string;
        constructor(Oid: string, Title: string, Type: string, IconUrlNormal?: string, IconUrlHighlight?: string);
    }
}
